@@ -267,6 +267,7 @@ impl std::fmt::Display for KalkValue {
                 result.pop(); // Trailing space
                 result.pop(); // Trailing space
                 result.pop(); // Trailing comma
+                result = result.trim().to_string();
                 result.push(']');
 
                 write!(f, "{}", result)
@@ -571,6 +572,21 @@ impl KalkValue {
         }
     }
 
+    pub fn is_finite(&self) -> bool {
+        //#[cfg(feature = "rug")]
+        if let KalkValue::Number(real, imaginary, _) = self {
+            real.is_finite() && imaginary.is_finite()
+        } else {
+            false
+        }
+        //#[cfg(not(feature = "rug"))]
+        //if let KalkValue::Number(real, imaginary, _) = self {
+        //    real.is_finite() && imaginary.is_finite()
+        //} else {
+        //    false
+        //}
+    }
+
     pub fn to_scientific_notation(
         &self,
         complex_number_type: ComplexNumberType,
@@ -1190,7 +1206,7 @@ pub fn format_number(input: f64) -> String {
 
 #[cfg(feature = "rug")]
 pub fn format_number_big(input: &Float) -> String {
-    if input.clone().log10() < 0f64 {
+    if input.clone().abs().log10() < 0f64 {
         return input.to_f64().to_string();
     }
 
